# Kubextract: ML Kubeflow Framework Generator
Kubextract is a framework generator for end-to-end machine learning development and automate kubeflow job deployment.

### How to use
- pip3
  - install pip3 package on your computer
  - run ```pip3 install kubextract --upgrade```
  - run ```kubextract```

- anaconda
  - install anaconda
  - create new python3 environment
  - use new environment ```conda activate <your_env>```
  - run ```pip install kubextract --upgrade```
  - run ```kubextract```

### Documentation
- see config documentation on ```docs/config```
- see architecture decision record on ```docs/adr```
- see example project on ```examples/```
